#pragma once

#include "ActorInterface.h"
#include "WASCommand.h"
#include "WASActor.h"

class CWASSendNote : public CWASCommand
{
public:
	CWASSendNote(CWASActor *pActor);
	~CWASSendNote(void);

	void SetParameter(NT_NOTE_SEND_DATA *pSendNoteData)
	{
		m_pSendNoteData = pSendNoteData;
	}

	void ExecuteAsync(void);

private:
	bool ParseAndEventFire(Json::Value * json);

protected:
	virtual void OnWasResponse(trid_t /*trid*/, bool /*bSuccess*/, int /*nWinINetErrorCode*/, int /*nHttpResponseCode*/, 
		LPCSTR /*szWasResCodeInHeader*/, 
		LPCSTR /*szWasResCodeInXml*/,
		Json::Value * /*json*/);

	virtual void OnRequestTimeout(CHttpFacade * /*pHttpF*/, DWORD /*dwSeconds*/);

private:
	NT_NOTE_SEND_DATA	*m_pSendNoteData;

	int					m_nErrorCode;
	WSTRING				m_strResponseMsg;
};



class CWASUnreadNoteCount : public CWASCommand
{
public:
	CWASUnreadNoteCount(CWASActor *pActor);
	~CWASUnreadNoteCount(void);

	void ExecuteAsync(void);

private:
	bool ParseAndEventFire(Json::Value * json);

protected:
	virtual void OnWasResponse(trid_t /*trid*/, bool /*bSuccess*/, int /*nWinINetErrorCode*/, int /*nHttpResponseCode*/, 
		LPCSTR /*szWasResCodeInHeader*/, 
		LPCSTR /*szWasResCodeInXml*/,
		Json::Value * /*json*/);
 
	virtual void OnRequestTimeout(CHttpFacade * /*pHttpF*/, DWORD /*dwSeconds*/);

private:
	int m_nUnreadNoteCount;
};




class CWASNoteSetReadStatus : public CWASCommand
{
public:
	CWASNoteSetReadStatus(CWASActor *pActor);
	~CWASNoteSetReadStatus(void);

	void SetParameter(UINT64 nNoteID, std::string strLanguage)
	{
		m_nNoteID = nNoteID;
		m_strLanguage = strLanguage;
	}

	void ExecuteAsync(void);

private:
	bool ParseAndEventFire(Json::Value * json);

protected:
	virtual void OnWasResponse(trid_t /*trid*/, bool /*bSuccess*/, int /*nWinINetErrorCode*/, int /*nHttpResponseCode*/, 
		LPCSTR /*szWasResCodeInHeader*/, 
		LPCSTR /*szWasResCodeInXml*/,
		Json::Value * /*json*/);

	virtual void OnRequestTimeout(CHttpFacade * /*pHttpF*/, DWORD /*dwSeconds*/);

private:
	UINT64		m_nNoteID;
	std::string	m_strLanguage;
};





class CWASGetRecvNoteInfo : public CWASCommand
{
public:
	CWASGetRecvNoteInfo(CWASActor *pActor);
	~CWASGetRecvNoteInfo(void);

	void SetParameter(UINT64 nNoteID, NTReqNoteInfoType reqType, std::string strLanguage, bool bIncludeToList)
	{
		m_nNoteID = nNoteID;
		m_strLanguage = strLanguage;
		m_bIncludeToList = bIncludeToList;
		m_reqType = reqType;
	}

	void ExecuteAsync(void);

private:
	bool ParseAndEventFire(Json::Value * json);

protected:
	virtual void OnWasResponse(trid_t /*trid*/, bool /*bSuccess*/, int /*nWinINetErrorCode*/, int /*nHttpResponseCode*/, 
		LPCSTR /*szWasResCodeInHeader*/, 
		LPCSTR /*szWasResCodeInXml*/,
		Json::Value * /*json*/);

	virtual void OnRequestTimeout(CHttpFacade * /*pHttpF*/, DWORD /*dwSeconds*/);

	void ClearNoteInfo();

private:
	UINT64				m_nNoteID;
	NTReqNoteInfoType	m_reqType;
	std::string			m_strLanguage;
	bool				m_bIncludeToList;

	NoteInfo			m_noteInfo;

};







class CWASDeleteAttachedFile : public CWASCommand
{
public:
	CWASDeleteAttachedFile(CWASActor *pActor);
	~CWASDeleteAttachedFile(void);

	void SetParameter(std::string strAttachID, int nIndex)
	{
		m_strAttachID = strAttachID;
		m_nIndex = nIndex;
	}

	void ExecuteAsync(void);

private:
	bool ParseAndEventFire(Json::Value * json);

protected:
	virtual void OnWasResponse(trid_t /*trid*/, bool /*bSuccess*/, int /*nWinINetErrorCode*/, int /*nHttpResponseCode*/, 
		LPCSTR /*szWasResCodeInHeader*/, 
		LPCSTR /*szWasResCodeInXml*/,
		Json::Value * /*json*/);

	virtual void OnRequestTimeout(CHttpFacade * /*pHttpF*/, DWORD /*dwSeconds*/);

private:
	std::string		m_strAttachID;
	int				m_nIndex;

	bool			m_bResult;
};






class CWASDeleteNote : public CWASCommand
{
public:
	CWASDeleteNote(CWASActor *pActor);
	~CWASDeleteNote(void);

	void SetParameter(UINT64 nNoteID, std::string strLanguage)
	{
		m_nNoteID = nNoteID;
		m_strLanguage = strLanguage;
	}

	void ExecuteAsync(void);

private:
	bool ParseAndEventFire(Json::Value * json);

protected:
	virtual void OnWasResponse(trid_t /*trid*/, bool /*bSuccess*/, int /*nWinINetErrorCode*/, int /*nHttpResponseCode*/, 
		LPCSTR /*szWasResCodeInHeader*/, 
		LPCSTR /*szWasResCodeInXml*/,
		Json::Value * /*json*/);

	virtual void OnRequestTimeout(CHttpFacade * /*pHttpF*/, DWORD /*dwSeconds*/);

private:
	UINT64			m_nNoteID;
	std::string		m_strLanguage;

	bool			m_bResult;
};






class CWASGetAttatchID : public CWASCommand
{
public:
	CWASGetAttatchID(CWASActor *pActor);
	~CWASGetAttatchID(void);

	void ExecuteAsync(void);

private:
	bool ParseAndEventFire(Json::Value * json);

protected:
	virtual void OnWasResponse(trid_t /*trid*/, bool /*bSuccess*/, int /*nWinINetErrorCode*/, int /*nHttpResponseCode*/, 
		LPCSTR /*szWasResCodeInHeader*/, 
		LPCSTR /*szWasResCodeInXml*/,
		Json::Value * /*json*/);

	virtual void OnRequestTimeout(CHttpFacade * /*pHttpF*/, DWORD /*dwSeconds*/);

private:
	std::string		m_strAttachID;
};





class CWASGetReplyBody : public CWASCommand
{
public:
	CWASGetReplyBody(CWASActor *pActor);
	~CWASGetReplyBody(void);

	void SetParameter(std::wstring strWriteMode, UINT64 nNoteID, std::string strLanguage)
	{
		m_strWriteMode = strWriteMode;
		m_nNoteID = nNoteID;
		m_strLanguage = strLanguage;
	}

	void ExecuteAsync(void);

private:
	bool ParseAndEventFire(Json::Value * json);

protected:
	virtual void OnWasResponse(trid_t /*trid*/, bool /*bSuccess*/, int /*nWinINetErrorCode*/, int /*nHttpResponseCode*/, 
		LPCSTR /*szWasResCodeInHeader*/, 
		LPCSTR /*szWasResCodeInXml*/,
		Json::Value * /*json*/);

	virtual void OnRequestTimeout(CHttpFacade * /*pHttpF*/, DWORD /*dwSeconds*/);

private:
	std::wstring	m_strWriteMode;
	UINT64			m_nNoteID;
	std::string		m_strLanguage;

	NoteReplyBody	m_replyBodyInfo;

};

